@@ -4,6 +4,7 @@ from pathlib import Path # Added for globbing
 from typing import TYPE_CHECKING, Callable, Optional, Tuple
 
 from tinycoder.unittest_runner import run_tests
+from tinycoder.coverage_tool import run_coverage_summary
 
 if TYPE_CHECKING:
     from tinycoder.file_manager import FileManager
@@ -246,10 +247,8 @@ class CommandHandler:
             if args_str:
                 # Log a truncated version of the prompt if it's long
                 prompt_preview = args_str[:50] + ('...' if len(args_str) > 50 else '')
-                self.logger.info(f"Switched to ASK mode. Processing prompt: \"{prompt_preview}\"")
                 return True, args_str  # Pass args_str as immediate_prompt_arg
             else:
-                self.logger.info("Switched to ASK mode. I will answer questions but not edit files.")
                 return True, None
 
         elif command == "/code":
@@ -257,10 +256,8 @@ class CommandHandler:
             if args_str:
                 # Log a truncated version of the prompt if it's long
                 prompt_preview = args_str[:50] + ('...' if len(args_str) > 50 else '')
-                self.logger.info(f"Switched to CODE mode. Processing prompt: \"{prompt_preview}\"")
                 return True, args_str  # Pass args_str as immediate_prompt_arg
             else:
-                self.logger.info("Switched to CODE mode. I will try to edit files.")
                 return True, None
         
         elif command == "/suggest_files":
@@ -285,17 +282,22 @@ class CommandHandler:
                 
                 if service_to_test:
                     self.logger.info(f"Docker detected. Running tests in '{service_to_test}' service...")
-                    # Common test commands, try pytest first
-                    test_command_to_run = "pytest" 
+                    # Prefer concise pytest output in containers: quiet, show only failures/errors, force color
+                    test_command_to_run = "pytest -q -r fE --color=yes"
                     self.docker_manager.run_command_in_service(service_to_test, test_command_to_run)
                 else:
                     self.logger.warning("Docker detected, but could not determine a service to run tests in. Running locally.")
                     run_tests(self.write_history_func, self.git_manager)
             else:
-                self.logger.info("No Docker environment detected. Running tests locally.")
                 run_tests(self.write_history_func, self.git_manager)
             return True, None
 
+        elif command == "/coverage":
+            if args_str:
+                self.logger.warning("/coverage command does not accept arguments.")
+            run_coverage_summary(self.write_history_func, self.git_manager, self.logger)
+            return True, None
+
         elif command == "/docker":
             if not self.docker_manager or not self.docker_manager.is_available:
                 self.logger.error("Docker integration is not available or enabled.")
@@ -451,6 +453,7 @@ class CommandHandler:
   /ask                        Switch to ASK mode (answer questions, no edits).
   /code                       Switch to CODE mode (make edits).
   /tests                      Run unit tests (runs in container if docker-compose.yml is present).
+  /coverage                   Run coverage summary (unittest discovery; summary per file and total).
   /docker ps                  Show status of Docker containers.
   /docker logs <service>      Stream logs from a Docker container.
   /docker restart <service>   Restart a Docker container.
