@@ -187,9 +187,6 @@ class GitManager:
                  self.logger.error(f"{COLORS['RED']}Failed to set global git config {config_key}: {stderr_set}{RESET}")
                  # Continue trying to set others if needed, but log the error
 
-    def get_last_commit_hash(self) -> Optional[str]:
-        return self.git_root
-
     def get_tracked_files_relative(self) -> List[str]:
         """Gets a list of all files currently tracked by git, relative to the repo root."""
         if not self.is_repo():
@@ -263,7 +260,7 @@ class GitManager:
         if ret != 0:
             self.logger.error(f"{COLORS['RED']}Failed to git add files: {stderr}{RESET}")
             return None
-        self.logger.info(f"GIT: Staged changes for: {COLORS['CYAN']}{', '.join(sorted(files_rel))}{RESET}")
+        self.logger.debug(f"GIT: Staged changes for: {COLORS['CYAN']}{', '.join(sorted(files_rel))}{RESET}")
 
         # Commit
         ret, stdout_commit, stderr_commit = self._run_git_command(
@@ -285,7 +282,7 @@ class GitManager:
         # Get the commit hash
         commit_hash = self.get_last_commit_hash()
         if commit_hash:
-            self.logger.info(f"Committed changes as {COLORS['GREEN']}{commit_hash}{RESET}")
+            self.logger.info(f"📑 Commit: {COLORS['GREEN']}{commit_hash}{RESET}")
             return commit_hash
         else:
             # Error getting hash already printed by get_last_commit_hash
